==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Es torna el sistema a la versió anterior. Espereu, si us plau...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Ha fallat tornar a la versió anterior.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia&apos;t</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Ha fallat l&apos;actualització.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>L&apos;actualització ha fallat: s&apos;ha interromput.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Les actualitzacions han fallat: error de DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Les actualitzacions han fallat: espai al disc insuficient.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Segur que voleu tornar a %1 de la còpia de seguretat de %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Cancel·la-ho i reinicia&apos;t</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Es torna el sistema a la versió anterior. Espereu, si us plau...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Ha fallat tornar a la versió anterior.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia&apos;t</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Ha fallat l&apos;actualització.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>L&apos;actualització ha fallat: s&apos;ha interromput.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Les actualitzacions han fallat: error de DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Les actualitzacions han fallat: espai al disc insuficient.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Segur que voleu tornar a %1 de la còpia de seguretat de %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Cancel·la-ho i reinicia&apos;t</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
</TS>
